*****************
``matplotlib.cm``
*****************

.. automodule:: matplotlib.cm
   :members:
   :undoc-members:
   :show-inheritance:

.. class:: ScalarMappable(colorizer, **kwargs)
   :canonical: matplotlib.colorizer._ScalarMappable

   .. automethod:: autoscale
   .. automethod:: autoscale_None
   .. automethod:: changed
   .. autoproperty:: colorbar
   .. automethod:: get_alpha
   .. automethod:: get_array
   .. automethod:: get_clim
   .. automethod:: get_cmap
   .. autoproperty:: norm
   .. automethod:: set_array
   .. automethod:: set_clim
   .. automethod:: set_cmap
   .. automethod:: set_norm
   .. automethod:: to_rgba
